pub enum DcmExpr {
Identity {
from: i32,
to: i32,
},
R1 {
angle_rad: f64,
from: i32,
to: i32,
},
R2 {
angle_rad: f64,
from: i32,
to: i32,
},
R3 {
angle_rad: f64,
from: i32,
to: i32,
},
Triad {
primary_axis: Box<VectorExpr>,
primary_vec: Box<VectorExpr>,
secondary_axis: Box<VectorExpr>,
secondary_vec: Box<VectorExpr>,
from: i32,
to: i32,
},
Quaternion {
x: f64,
y: f64,
z: f64,
w: f64,
from: i32,
to: i32,
},
RIC {
state: Box<StateSpec>,
from: i32,
to: i32,
},
VNC {
state: Box<StateSpec>,
from: i32,
to: i32,
},
RCN {
state: Box<StateSpec>,
from: i32,
to: i32,
},
SEZ {
state: Box<StateSpec>,
from: i32,
to: i32,
},
}Available on crate feature
analysis only.Expand description
DCM Expr defines an expression built from a DCM. At the moment, this does not allow for combining rotations.
Variants
Identity
R1
R2
R3
Triad
Fields

primary_axis: Box<VectorExpr>
primary_vec: Box<VectorExpr>
secondary_axis: Box<VectorExpr>
secondary_vec: Box<VectorExpr>Quaternion
RIC
VNC
RCN
SEZ
Implementations