pub enum VectorExpr {
Fixed {
x: f64,
y: f64,
z: f64,
},
Radius(StateSpec),
Velocity(StateSpec),
OrbitalMomentum(StateSpec),
EccentricityVector(StateSpec),
CrossProduct {
a: Box<Self>,
b: Box<Self>,
},
Unit(Box<Self>),
Add {
a: Box<Self>,
b: Box<Self>,
},
Negate(Box<Self>),
VecProjection {
a: Box<Self>,
b: Box<Self>,
},
Project {
v: Box<Self>,
frame: Box<OrthogonalFrame>,
plane: Option<Plane>,
},
Rotate {
v: Box<Self>,
dcm: Box<DcmExpr>,
},
}analysis only.Expand description
VectorExpr defines a vector expression, which can either be computed from a state, or from a fixed definition.
API note
This VectorExpr is different from the Python class because of a limitation in the support for recursive types in PyO3.
Variants
Fixed
Radius(StateSpec)
Radius/position vector of this state specification
Velocity(StateSpec)
Velocity vector of this state specification
OrbitalMomentum(StateSpec)
Orbital moment (H) vector of this state specification
EccentricityVector(StateSpec)
Eccentricity vector of this state specification
CrossProduct
Cross product between two vector expression
Unit(Box<Self>)
Unit vector of this vector expression, returns zero vector if norm less than 1e-12
Add
Adds two vectors together
Negate(Box<Self>)
Negate a vector
VecProjection
Vector projection of a onto b
Project
Multiplies the DCM of thr frame with this vector, thereby rotating it into the provided orthogonal frame, optionally projecting onto the plan, optionally projecting onto the plane
Rotate
Allows rotating a given VectorExpr by the provided DCM Expression, returning another VectorExpr
Implementations
Sourceimpl VectorExpr
impl VectorExpr